@@ -98,11 +98,11 @@ DBIx::Raw - Maintain control of SQL queries while still having a layer of abstra
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =head1 SYNOPSIS
 
@@ -364,7 +364,7 @@ This sets the crypt key to use if L</use_old_crypt> is set to true. Default is t
 =head2 raw
 
 L</raw> is a very versitile subroutine, and it can be called in three contexts. L</raw> should only be used to make a query that
-returns values for one record, or a query that returns no results (such as an UPDATE or INSERT query). If you need to have multiple
+returns values for one record, or a query that returns no results (such as an INSERT query). If you need to have multiple
 results returned, see one of the subroutines below.
 
 =head3 SCALAR CONTEXT
@@ -374,7 +374,10 @@ L</raw> can be called in a scalar context to only return one value, or in a unde
     #select
     my $name = $db->raw("SELECT name FROM people WHERE id=1");
 
-    #update
+    #update with number of rows updated returned
+    my $num_rows_updated = $db->raw("UPDATE people SET name=? WHERE id=1", 'Frank');
+ 
+    #update in undef context, nothing returned.
     $db->raw("UPDATE people SET name=? WHERE id=1", 'Frank');
 
     #insert
@@ -448,7 +451,7 @@ sub raw {
   		my $return_value = $self->sth->rows();
 		push @return_values, $return_value;
 	}
-	elsif(($params->{query} =~ /SELECT /sig) || ($params->{query} =~ /SHOW /sig)) {
+    elsif(($params->{query} =~ /SELECT /sig) || ($params->{query} =~ /SHOW /sig)) {
   		unless($params->{query} =~ /INSERT INTO (.*?)SELECT /sig) {
   			if($return_type eq 'hash') {
 				return unless $params->{href} = $self->sth->fetchrow_hashref; #handles undef case
@@ -468,7 +471,7 @@ sub raw {
 				}
 			}
 		} 
-	} 
+	}
 
 	$self->sth->finish or $self->_perish($params);
 
@@ -1115,7 +1118,8 @@ sub update {
 		}
 		else { 
             # TODO: write update encrypt tests
-            if ($params->{encrypt} and first { $_ eq $key } @{$params->{encrypt}}) {
+            if ((defined $params->{encrypt} and $params->{encrypt} eq '*') 
+                    or ($params->{encrypt} and first { $_ eq $key } @{$params->{encrypt}})) {
                 push @encrypt, scalar(@vals);
             }
 
